@@ -17,7 +17,7 @@ class Deployment(syst3m.objects.Object):
 		# the domain.
 		domain=None,
 		# the database path.
-		database_path=None,
+		database=None,
 		# the remote.
 		remote=None,
 		# the vps ip (if remote is vps else leave default).
@@ -44,7 +44,7 @@ class Deployment(syst3m.objects.Object):
 		self.root = root
 		self.library = library
 		self.domain = domain
-		self.database_path = database_path
+		self.database = database
 		self.remote = remote
 
 		self.country_code = country_code
@@ -62,7 +62,7 @@ class Deployment(syst3m.objects.Object):
 
 		#
 	# configure also for remove:vps & remote:local.
-	def configure(self, reinstall=False, log_level=0):
+	def configure(self, reinstall=False, log_level=0, loader=None):
 		
 		# check arguments.
 		if self.remote in ["vps"]:
@@ -79,10 +79,12 @@ class Deployment(syst3m.objects.Object):
 		
 		# configure before loader.
 		if reinstall:
-			os.system(f"rm -fr {self.database_path}/tls/dhparam.pem")
-		if not Files.exists(f"{self.database_path}/tls/dhparam.pem"):
+			os.system(f"rm -fr {self.database}/tls/dhparam.pem")
+		if not Files.exists(f"{self.database}/tls/dhparam.pem"):
+			if loader != None: loader.hold()
 			tmp = "/tmp/dhparam.pem"
-			os.system(f"sudo openssl dhparam -out {tmp} 4096 && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {tmp} && mv {tmp} {self.database_path}/tls/dhparam.pem && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {self.database_path}/tls/dhparam.pem")
+			os.system(f"sudo openssl dhparam -out {tmp} 4096 && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {tmp} && mv {tmp} {self.database}/tls/dhparam.pem && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {self.database}/tls/dhparam.pem")
+			if loader != None: loader.release()
 
 		# loader.
 		if log_level >= 0: loader = syst3m.console.Loader(f"Configuring deployment of website {self.domain} ...")
@@ -109,16 +111,16 @@ class Deployment(syst3m.objects.Object):
 			output = syst3m.utils.__execute_script__(f"curl https://raw.githubusercontent.com/vandenberghinc/public-storage/master/w3bsite/favicon.ico -o {self.root}/static/favicon.ico")
 
 		# tls.
-		if not Files.exists(f"{self.database_path}/tls/server.key") and not Files.exists(f"{self.database_path}/tls/server.crt"):
+		if not Files.exists(f"{self.database}/tls/server.key") and not Files.exists(f"{self.database}/tls/server.crt"):
 			response = self.generate_tls(log_level=log_level)
 			if not response.success: 
 				if log_level >= 0: loader.stop(success=False)
 				return response
 
 		# database.
-		if not Files.exists(self.database_path): 
-			os.system(f"sudo mkdir -p {self.database_path} && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {self.database_path} && sudo chmod 770 {self.database_path}")
-		if not Files.exists(f"{self.database_path}/logs"): os.mkdir(f"{self.database_path}/logs")
+		if not Files.exists(self.database): 
+			os.system(f"sudo mkdir -p {self.database} && sudo chown {syst3m.defaults.vars.user}:{syst3m.defaults.vars.group} {self.database} && sudo chmod 770 {self.database}")
+		if not Files.exists(f"{self.database}/logs"): os.mkdir(f"{self.database}/logs")
 
 		# deployment.
 		if not Files.exists(f"{self.root}/deployment"): os.mkdir(f"{self.root}/deployment")
@@ -127,7 +129,7 @@ class Deployment(syst3m.objects.Object):
 			"***ROOT***":clean_root, 
 			"***USER***":username, 
 			"***DOMAIN***":self.domain,
-			"***DATABASE***":self.database_path,
+			"***DATABASE***":self.database,
 			"***USER***":syst3m.defaults.vars.user,
 		}
 		for path in Files.Directory(path=f"{SOURCE_PATH}/classes/deployment/lib/").paths():
@@ -150,6 +152,7 @@ class Deployment(syst3m.objects.Object):
 	def deploy(self, code_update=False, reinstall=False, log_level=0):
 			
 		# loader.
+		loader = None
 		if log_level >= 0: loader = syst3m.console.Loader(f"Deploying domain {self.domain} ...")
 
 		# check namecheap domain.
@@ -174,26 +177,26 @@ class Deployment(syst3m.objects.Object):
 			return r3sponse.error(f"Unsupported operating system [{OS}].")
 		
 		# configure.
-		response = self.configure(reinstall=reinstall, log_level=log_level)
+		response = self.configure(reinstall=reinstall, log_level=log_level, loader=loader)
 		if not response.success: 
 			if log_level >= 0: loader.stop(quiet=True)
 			return response
 
 		# check tls domain.
-		if not Files.exists(f"{self.database_path}/tls/.domain"): Files.save(f"{self.database_path}/tls/.domain", self.domain)
-		tls_domain = Files.load(f"{self.database_path}/tls/.domain").replace('\n',"")
+		if not Files.exists(f"{self.database}/tls/.domain"): Files.save(f"{self.database}/tls/.domain", self.domain)
+		tls_domain = Files.load(f"{self.database}/tls/.domain").replace('\n',"")
 		if tls_domain != self.domain:
 			if log_level >= 0: loader.stop(success=False)
-			return r3sponse.error(f"TLS Certificate mis match. Installed tls certificate [{self.database_path}/tls] is linked to domain {tls_domain}, not specified domain {self.domain}.", log_level=0)
+			return r3sponse.error(f"TLS Certificate mis match. Installed tls certificate [{self.database}/tls] is linked to domain {tls_domain}, not specified domain {self.domain}.", log_level=0)
 		
 		# checks.
-		if not Files.exists(f"{self.database_path}/tls/server.key") or not Files.exists(f"{self.database_path}/tls/server.crt"):
+		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
 			if log_level >= 0: loader.stop(success=False)
 			return r3sponse.error("No tls certificate exists.\nExecute the following command to generate a tls certificate:\n$ ./website.py --generate-tls", log_level=log_level)
-		if not Files.exists(f"{self.database_path}/tls/signed.server.crt"):
+		if not Files.exists(f"{self.database}/tls/signed.server.crt"):
 			if log_level >= 0: loader.stop(success=False)
 			return r3sponse.error("No activated tls certificate exists. \nExecute the following command to activate the generated tls certificate:\n$ ./website.py --activate-tls", log_level=log_level)
-		if not Files.exists(f"{self.database_path}/tls/server.ca-bundle"):
+		if not Files.exists(f"{self.database}/tls/server.ca-bundle"):
 			if log_level >= 0: loader.stop(success=False)
 			return r3sponse.error("No bundled tls certificate exists. \nDownload the signed certificate send to your email, extr the zip to a directory and execute \n$ ./website.py --bundle-tls /path/to/extracted/directory/", log_level=log_level)
 		
@@ -220,11 +223,11 @@ class Deployment(syst3m.objects.Object):
 		# check base.
 		base = f"{self.root}/.secrets/"
 		if not Files.exists(base): os.mkdir(base)
-		base = f"{self.database_path}/tls"
+		base = f"{self.database}/tls"
 		if not Files.exists(base): os.mkdir(base)
 
 		# check duplicate.
-		if Files.exists(f"{self.database_path}/tls/server.key") or Files.exists(f"{self.database_path}/tls/server.crt"):
+		if Files.exists(f"{self.database}/tls/server.key") or Files.exists(f"{self.database}/tls/server.crt"):
 			return r3sponse.error("The tls certificate already exists.", log_level=log_level)
 
 		# generate.
@@ -253,24 +256,24 @@ class Deployment(syst3m.objects.Object):
 		""")
 
 		# handler.
-		if not Files.exists(f"{self.database_path}/tls/server.key") or not Files.exists(f"{self.database_path}/tls/server.crt"):
+		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
 			if log_level >= 0: loader.stop(success=False)
 			os.system(f"rm -fr {base}")
 			return r3sponse.error(f"Failed to generate a tls certificate.", log_level=log_level)
 		else:
 			if log_level >= 0: loader.stop()
-			Files.save(f"{self.database_path}/tls/.domain", self.domain)
+			Files.save(f"{self.database}/tls/.domain", self.domain)
 			return r3sponse.success(f"Successfully generated a tls certificate.", log_level=log_level)
 
 		#
 	def activate_tls(self, log_level=0):
 
 		# check existsance.
-		if not Files.exists(f"{self.database_path}/tls/server.key") or not Files.exists(f"{self.database_path}/tls/server.crt"):
+		if not Files.exists(f"{self.database}/tls/server.key") or not Files.exists(f"{self.database}/tls/server.crt"):
 			return r3sponse.error("No generated tls certificate exists.", log_level=log_level)
 
 		# check duplicate.
-		if Files.exists(f"{self.database_path}/tls/signed.server.key"):
+		if Files.exists(f"{self.database}/tls/signed.server.key"):
 			return r3sponse.error("A signed tls certificate already exists.", log_level=log_level)
 
 		response = self.namecheap.get_tls()
@@ -367,12 +370,12 @@ class Deployment(syst3m.objects.Object):
 
 		# bundle ca.
 		syst3m.utils.__execute_script__(f"""
-			cat {directory}/AAACertificateServices.crt {directory}/SectigoRSADomainValidationSecureServerCA.crt {directory}/syst3m.defaults.vars.userTrustRSAAAACA.crt > {self.database_path}/tls/server.ca-bundle
-			cat {directory}/server.crt {self.database_path}/tls/server.ca-bundle > {self.database_path}/tls/signed.server.crt
-			mv {self.database_path}/tls/server.crt {self.database_path}/tls/original.server.crt
-			cp {self.database_path}/tls/signed.server.crt {self.database_path}/tls/server.crt
+			cat {directory}/AAACertificateServices.crt {directory}/SectigoRSADomainValidationSecureServerCA.crt {directory}/syst3m.defaults.vars.userTrustRSAAAACA.crt > {self.database}/tls/server.ca-bundle
+			cat {directory}/server.crt {self.database}/tls/server.ca-bundle > {self.database}/tls/signed.server.crt
+			mv {self.database}/tls/server.crt {self.database}/tls/original.server.crt
+			cp {self.database}/tls/signed.server.crt {self.database}/tls/server.crt
 			""")
-		if Files.exists(f"{self.database_path}/tls/signed.server.crt"):
+		if Files.exists(f"{self.database}/tls/signed.server.crt"):
 			return r3sponse.success(f"Successfully bundled ssl certificate [{directory}].", log_level=log_level)
 		else:
 			return r3sponse.error(f"Failed to bundle ssl certificate [{directory}].", log_level=log_level)
